@@ -13,9 +13,14 @@ Date of create file: 01.28.2023
 # Main logic libraries
 from aiohttp import ClientSession, client_exceptions
 import json
+# Logging libraries
+import logging
 # Other libraries
 from typing import Callable
-from . import *
+from . import apiPaths
+from . import dataClasses
+from . import apiSpbStuRuzExeptions
+from . import LogConfig
 
 
 class ApiSpbStuRuz:
